# InlineResponse200WebResults

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**title** | **str** | The title of the webpage. | [optional] 
**url** | **str** | The full URL for the webpage. | [optional] 
**description** | **str** | A summary or snippet from the webpage. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

